==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA04S.sql <==
/****************************************************************************/
/* GEA04 ( ｺｰﾄﾞ定義 )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GEA04 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              varchar           (   30 )                  NOT NULL            /*  20 項目         */
 , CODE             varchar           (   30 )                  NOT NULL            /*  30 ｺｰﾄﾞ         */
 , SEQNO            INTEGER                         DEFAULT 0   NOT NULL            /*  40 表示順       */
 , CDKH             varchar           (    1 )                                      /*  50 改廃ｺｰﾄﾞ     */
 , KBSAKU           varchar           (    1 )      DEFAULT '1' NOT NULL            /*  60 作成区分     */
 , RELEASE_NOTES    varchar           (  120 )                                      /*  70 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar           (   20 )                                      /*  80 設変番号     */
 , CODEGRP          varchar           (   20 )                                      /*  90 ｺｰﾄﾞｸﾞﾙｰﾌﾟ   */
 , COMMENTS         varchar           (  500 )                                      /* 100 ｺﾒﾝﾄ         */
 , CODELVL          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 110 階層         */
 , CODE_PARAM       varchar           (  200 )                                      /* 120 ｺｰﾄﾞﾊﾟﾗﾒｰﾀ   */
 , ROLES            varchar           ( 2000 )                                      /* 130 ﾛｰﾙｽﾞ        */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET           varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA04S.sql <==
/****************************************************************************/
/* GEA04 ( ｺｰﾄﾞ定義 )                                                       */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GEA04 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              varchar           (   30 )                  NOT NULL            /*  20 項目         */
 , CODE             varchar           (   30 )                  NOT NULL            /*  30 ｺｰﾄﾞ         */
 , SEQNO            INTEGER                         DEFAULT 0   NOT NULL            /*  40 表示順       */
 , CDKH             varchar           (    1 )                                      /*  50 改廃ｺｰﾄﾞ     */
 , KBSAKU           varchar           (    1 )      DEFAULT '1' NOT NULL            /*  60 作成区分     */
 , RELEASE_NOTES    varchar           (  120 )                                      /*  70 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar           (   20 )                                      /*  80 設変番号     */
 , CODEGRP          varchar           (   20 )                                      /*  90 ｺｰﾄﾞｸﾞﾙｰﾌﾟ   */
 , COMMENTS         varchar           (  500 )                                      /* 100 ｺﾒﾝﾄ         */
 , CODELVL          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 110 階層         */
 , CODE_PARAM       varchar           (  200 )                                      /* 120 ｺｰﾄﾞﾊﾟﾗﾒｰﾀ   */
 , ROLES            varchar           ( 2000 )                                      /* 130 ﾛｰﾙｽﾞ        */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar           (   14 )                                      /* 820 作成日時     */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET           varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者       */
);
